@@ -1,5 +1,5 @@
 """
-statmech: Pythonic Finite State Machine
+statmach: Pythonic Finite State Machine
 
 See ``__description__`` below or (better) ``README.md`` file in ``__repository__`` for more info.
 """
@@ -7,9 +7,9 @@ See ``__description__`` below or (better) ``README.md`` file in ``__repository__
 __author__ = "Howard C Lovatt"
 __copyright__ = "Howard C Lovatt, 2021 onwards."
 __license__ = "MIT https://opensource.org/licenses/MIT."
-__repository__ = "https://github.com/hlovatt/statmech"
+__repository__ = "https://github.com/hlovatt/statmach"
 __description__ = "Pythonic Finite State Machine with both action outputs (Mearly) and state outputs (Moore)"
-__version__ = "1.0.1"  # Version set by https://github.com/hlovatt/tag2ver
+__version__ = "1.0.2"  # Version set by https://github.com/hlovatt/tag2ver
 
 import sys
 
